import java.io.Closeable;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.Inet4Address;
import java.net.ServerSocket;
import java.net.Socket;

/**
 * Implements a server that waits for a single remote client
 *
 */
public class GameServer implements Closeable, AutoCloseable {
	private ServerSocket server;
	private Socket client;

	/**
	 * Initialize a server, listening on the given port
	 * @param port The port number to use
	 */
	public GameServer() throws IOException {
		int port = 8881;
		server = new ServerSocket(port);
		System.out.println("Wait for connection.\nIP:"
				+ Inet4Address.getLocalHost().getHostAddress() + ", Port:"
				+ port);
		client = server.accept();
	}

	/**
	 * Returns an input stream representing the input from 
	 * the remote client
	 * @return The input stream
	 */
	public InputStream getInputStream() throws IOException {
		return client.getInputStream();
	}

	/**
	 * Returns an output stream that sends its data to the remote client
	 * @return An output stream
	 */
	public OutputStream getOutputStream() throws IOException {
		return client.getOutputStream();
	}

	@Override
	public void close() throws IOException {
		client.close();
		server.close();
	}

}
